@@ -3,52 +3,51 @@ package Padre::Plugin::SpellCheck::Preferences;
 use warnings;
 use strict;
 
+use Try::Tiny;
 use Padre::Logger;
 use Padre::Util                                 ();
 use Padre::Locale                               ();
 use Padre::Unload                               ();
 use Padre::Plugin::SpellCheck::FBP::Preferences ();
 
-our $VERSION = '1.24';
+our $VERSION = '1.25';
 our @ISA     = qw{
 	Padre::Plugin::SpellCheck::FBP::Preferences
+	Padre::Plugin
 };
-# use Data::Printer {
-	# caller_info => 1,
-	# colored     => 1,
-# };
+
 
 #######
 # Method new
 #######
 sub new {
-	my $class   = shift;
-	my $_parent = shift; # parent $self
+	my $class = shift;
+	my $main  = shift;
 
 	# Create the dialog
-	my $self = $class->SUPER::new( $_parent->main );
-
-	# for access to P-P-SpellCheck DB config
-	$self->{_parent} = $_parent;
+	my $self = $class->SUPER::new($main);
 
 	# define where to display main dialog
 	$self->CenterOnParent;
-
-	$self->set_up;
+	$self->SetTitle( sprintf( Wx::gettext('Spell-Checker-Preferences v%s'), $VERSION ) );
+	$self->_set_up;
 
 	return $self;
 }
 
 #######
-# Method set_up
+# Method _set_up
 #######
-sub set_up {
+sub _set_up {
 	my $self = shift;
 
-	# $self->{dictionary} = 'Aspell';
-	$self->{dictionary} = $self->{_parent}->config_read->{Engine};
-
-	# print " dictionary/engine = $self->{dictionary}\n";
+	# set prefered dictionary from config
+	try {
+		$self->{dictionary} = $self->config_read->{Engine};
+	}
+	catch {
+		$self->{dictionary} = 'Aspell';
+	};
 
 	if ( $self->{dictionary} eq 'Aspell' ) {
 
@@ -61,7 +60,7 @@ sub set_up {
 	}
 
 	# update dialog with locally install dictionaries;
-	$self->display_dictionaries;
+	$self->_display_dictionaries;
 
 	return;
 }
@@ -74,12 +73,8 @@ sub _local_aspell_dictionaries {
 
 	my @local_dictionaries_names = ();
 
-	eval { require Text::Aspell; };
-	if ($@) {
-		$self->{local_dictionaries_names} = \@local_dictionaries_names;
-		print "Text::Aspell is not installed\n";
-		return;
-	} else {
+	try {
+		require Text::Aspell;
 		my $speller = Text::Aspell->new;
 
 		my @local_dictionaries = grep { $_ =~ /^\w+$/ } map { $_->{name} } $speller->dictionary_info;
@@ -87,7 +82,6 @@ sub _local_aspell_dictionaries {
 		TRACE("locally installed dictionaries found = @local_dictionaries") if DEBUG;
 		TRACE("iso to dictionary names = $self->{dictionary_names}")        if DEBUG;
 
-		#TODO compose method local iso to padre names
 		for (@local_dictionaries) {
 			push( @local_dictionaries_names, $self->padre_locale_label($_) );
 			$self->{dictionary_names}{$_} = $self->padre_locale_label($_);
@@ -97,10 +91,15 @@ sub _local_aspell_dictionaries {
 		$self->{local_dictionaries_names} = \@local_dictionaries_names;
 
 		TRACE("local dictionaries names = $self->{local_dictionaries_names}") if DEBUG;
-		return;
 	}
+	catch {
+		$self->{local_dictionaries_names} = \@local_dictionaries_names;
+		$self->main->info( Wx::gettext('Text::Aspell is not installed') );
+	};
+	return;
 }
 
+
 #######
 # Method _local_aspell_dictionaries
 #######
@@ -109,14 +108,9 @@ sub _local_hunspell_dictionaries {
 
 	my @local_dictionaries_names;
 	my @local_dictionaries;
-	eval { require Text::Hunspell; };
-	if ($@) {
-		$self->{local_dictionaries_names} = \@local_dictionaries_names;
-		print "Text::Hunspell is not installed\n";
-
-		return;
-	} else {
 
+	try {
+		require Text::Hunspell;
 		require Padre::Util;
 		my $speller = Padre::Util::run_in_directory_two('hunspell -D </dev/null');
 		chomp $speller;
@@ -151,18 +145,29 @@ sub _local_hunspell_dictionaries {
 		@local_dictionaries_names = sort @local_dictionaries_names;
 		$self->{local_dictionaries_names} = \@local_dictionaries_names;
 		TRACE("local dictionaries names = $self->{local_dictionaries_names}") if DEBUG;
-		return;
 	}
+	catch {
+		$self->{local_dictionaries_names} = \@local_dictionaries_names;
+		$self->main->info( Wx::gettext('Text::Hunspell is not installed') );
+	};
+	return;
 }
 
 #######
-# Method display_dictionaries
+# Method _display_dictionaries
 #######
-sub display_dictionaries {
+sub _display_dictionaries {
 	my $self = shift;
-	my $main = $self->main;
 
-	my $prefered_dictionary = $self->{_parent}->config_read->{ $self->{dictionary} };
+	# my $main = $self->main;
+
+	my $prefered_dictionary;
+	try {
+		$prefered_dictionary = $self->config_read->{ $self->{dictionary} };
+	}
+	catch {
+		$prefered_dictionary = 'Aspell';
+	};
 
 	TRACE("iso prefered_dictionary = $prefered_dictionary ") if DEBUG;
 
@@ -208,17 +213,12 @@ sub _on_button_save_clicked {
 	TRACE("selected dictionary iso = $select_dictionary_iso ") if DEBUG;
 
 	# save config info
-	my $config = $self->{_parent}->config_read;
+	my $config = $self->config_read;
 	$config->{ $self->{dictionary} } = $select_dictionary_iso;
 	$config->{Engine} = $self->{dictionary};
-	$self->{_parent}->config_write($config);
+	$self->config_write($config);
 
-	#this is naff
-	# TRACE("Saved P-P-SpellCheck config DB = $self->{_parent}->config_read ") if DEBUG;
-
-	# p $self->{_parent}->config_read;
-
-	$self->{_parent}->clean_dialog;
+	$self->Hide;
 	return;
 }
 
@@ -236,7 +236,7 @@ sub on_dictionary_chosen {
 		$self->_local_hunspell_dictionaries;
 	}
 
-	$self->display_dictionaries;
+	$self->_display_dictionaries;
 
 	return;
 }
@@ -250,8 +250,6 @@ sub padre_locale_label {
 	my $local_dictionary = shift;
 
 	my $lc_local_dictionary = lc( $local_dictionary ? $local_dictionary : 'en_GB' );
-
-	# my $lc_local_dictionary = lc $local_dictionary;
 	$lc_local_dictionary =~ s/_/-/;
 	require Padre::Locale;
 	my $label = Padre::Locale::label($lc_local_dictionary);
@@ -259,12 +257,79 @@ sub padre_locale_label {
 	return $label;
 }
 
-
 1;
 
 __END__
 
+=pod
+
+=head1 NAME
+
+Padre::Plugin::SpellCheck::Preferences - Check spelling in Padre, The Perl IDE
+
+=head1 VERSION
+
+version 1.25
+
+=head1 DESCRIPTION
+
+This module handles the Preferences dialogue window that is used to set your 
+chosen dictionary and preferred language.
+
+
+=head1 METHODS
+
+=over 2
+
+=item * new
+
+	$self->{dialog} = Padre::Plugin::SpellCheck::Preferences->new( $self );
+
+Create and return a new dialogue window. 
+
+=item * on_dictionary_chosen
+event handler
+
+=item * padre_locale_label
+
+uses Padre::Local to convert language iso693_iso3166 to utf8text strings
+
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+Throws an info on the status bar if you try to select a language if dictionary not installed
+
+=head1 DEPENDENCIES
+
+Padre, Padre::Plugin::SpellCheck::FBP::Preferences, and either or ( Text::Hunspell or Text::Aspell )
+
+=head1 SEE ALSO
+
+For all related information (bug reporting, source code repository,
+etc.), refer to L<Padre::Plugin::SpellCheck>.
+
+=head1 AUTHORS
+
+Kevin Dawson E<lt>bowtie@cpan.orgE<gt>
+
+Ahmad M. Zawawi E<lt>ahmad.zawawi@gmail.comE<gt>
+
+Fayland Lam E<lt>fayland@gmail.comE<gt>
+
+Jerome Quelin E<lt>jquelin@gmail.comE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Fayland Lam, Jerome Quelin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
 # Copyright 2008-2012 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl 5 itself.
\ No newline at end of file
+# modify it under the same terms as Perl 5 itself.
